pub fn ensure_initialized()Expand description
Ensure FFmpeg is initialized.
This function is idempotent and can be called multiple times safely. It will only perform initialization once.
pub fn ensure_initialized()Ensure FFmpeg is initialized.
This function is idempotent and can be called multiple times safely. It will only perform initialization once.